@@ -12,62 +12,25 @@ from marshmallow_peewee import ModelSchema, ForeignKey
 
 from ..handler import RESTBase, RESTOptions
 from ..errors import APIError
-from ..filters import Filter, Filters
 
 from .openapi import PeeweeOpenAPIMixin
+from .filters import PWFilters
+from .sorting import PWSorting
 
 
 # XXX: Patch apispec.MarshmallowPlugin to support ForeignKeyField
 MarshmallowPlugin.Converter.field_mapping[ForeignKey] = ("integer", None)
 
 
-class PWFilter(Filter):
-    """Support Peewee."""
-
-    operators = Filter.operators
-    operators['$in'] = lambda f, v: f << v
-    operators['$none'] = lambda f, v: f >> v
-    operators['$like'] = lambda f, v: f % v
-    operators['$ilike'] = lambda f, v: f ** v
-    operators['$contains'] = lambda f, v: f.contains(v)
-    operators['$starts'] = lambda f, v: f.startswith(v)
-    operators['$ends'] = lambda f, v: f.endswith(v)
-    operators['$between'] = lambda f, v: f.between(*v)
-    operators['$regexp'] = lambda f, v: f.regexp(v)
-
-    list_ops = Filter.list_ops + ['$between']
-
-    def __init__(self, name: str, *, pw_field: pw.Field = None, **kwargs):
-        """Support custom model fields."""
-        super(PWFilter, self).__init__(name, **kwargs)
-        self.pw_field = pw_field
-
-    def apply(self, collection: pw.Query, *ops: t.Tuple[t.Callable, t.Any],
-              handler: PWRESTBase = None, **kwargs) -> pw.Query:
-        """Apply the filters to Peewee QuerySet.."""
-        pw_field = (
-            self.pw_field or handler and handler.meta.model._meta.fields.get(self.field.attribute))
-        if pw_field and ops:
-            return self.query(collection, pw_field, *ops, **kwargs)
-        return collection
-
-    def query(self, query: pw.Query, column: pw.Field, *ops: t.Tuple, **kwargs) -> pw.Query:
-        """Filter a query."""
-        return query.where(*[op(column, val) for op, val in ops])
-
-
-class PWFilters(Filters):
-    """Bind Peewee filter class."""
-
-    FILTER_CLASS = PWFilter
-
-
 class PWRESTOptions(RESTOptions):
     """Support Peewee."""
 
     # Base filters class
     filters_cls: t.Type[PWFilters] = PWFilters
 
+    # Base sorting class
+    sorting_cls: t.Type[PWSorting] = PWSorting
+
     # Schema auto generation params
     schema_base: t.Type[ModelSchema] = ModelSchema
 
@@ -88,11 +51,6 @@ class PWRESTOptions(RESTOptions):
 
         super(PWRESTOptions, self).setup(cls)
 
-        # Setup sorting
-        self.sorting = dict(
-            (isinstance(n, pw.Field) and n.name or n, prop)
-            for (n, prop) in self.sorting.items())
-
     def setup_schema_meta(self, cls):
         """Prepare a schema."""
         return type('Meta', (object,), dict(
@@ -131,28 +89,6 @@ class PWRESTBase(RESTBase):
         except self.meta.model.DoesNotExist:
             raise APIError.NOT_FOUND('Resource not found')
 
-    async def sort(self, request: muffin.Request,
-                   *sorting: t.Tuple[str, bool], **options) -> pw.Query:
-        """Sort the current collection."""
-        order_by = []
-        for name, desc in sorting:
-            field = self.meta.sorting.get(name)
-            if field and not isinstance(field, pw.Field):
-                field = self.meta.model._meta.fields.get(name)
-
-            if field is None:
-                continue
-
-            if desc:
-                field = field.desc()  # type: ignore
-
-            order_by.append(field)
-
-        if order_by:
-            return self.collection.order_by(*order_by)
-
-        return self.collection
-
     async def paginate(self, request: muffin.Request, *, limit: int = 0,
                        offset: int = 0) -> t.Tuple[pw.Query, int]:
         """Paginate the collection."""
